# awsmfunc

### Requirements
* Python 3.9 minimum
* [vapoursynth](http://www.vapoursynth.com/)
* [numpy](https://numpy.org/)
* [RemapFrames](https://github.com/Irrational-Encoding-Wizardry/Vapoursynth-RemapFrames)
* [FillBorders](https://github.com/dubhater/vapoursynth-fillborders)

Optional plugins:
* [vs-placebo](https://github.com/Lypheo/vs-placebo)
* [vapoursynth-descale](https://github.com/Irrational-Encoding-Wizardry/vapoursynth-descale)
* [vapoursynth-bilateral](https://github.com/HomeOfVapourSynthEvolution/VapourSynth-Bilateral)
* [vsfpng](https://github.com/Mikewando/vsfpng)

### Setting up
```console
pip install --user awsmfunc
```
From `git`
```console
pip install --user git+https://github.com/OpusGang/awsmfunc.git
```

&nbsp;

### Updating everything

	pip install --user --upgrade --force-reinstall .

#### Dependencies
* [rekt](https://github.com/OpusGang/rekt)
* [vsutil](https://github.com/Irrational-Encoding-Wizardry/vsutil)

#### Recommended VS Community Python Modules 
* [See Wiki](https://github.com/OpusGang/awsmfunc/wiki/Recommended-VS-Community-Python-Modules)

### Contact
- **IRC Channel**: `#OpusGang` on `irc.libera.chat`
